pro generic, datafile
; plots y vs. x with errors (first five rows) in a postscript file plot.ps

; features a number of extraneous lines for illustrative purposes,
; including a screen plot of y vs. the the row number

array = FLTARR(3,5)          ;create a 3 (cols) X 5 (rows) floating point array
OPENR, unit, datafile, /GET_LUN ;open file for reading, allocating a free unit
READF, unit, array ;read the contents of the file into the array
HELP, ARRAY
x = REFORM(array[0,*]) ;create a vector consisting of the 1st column of array
y = REFORM(array[1,*]) ;create a vector consisting of the 2nd column of array
y_err = REFORM(array[2,*]) ;create a vector consisting of the 3rd column of array
HELP, x, y, y_err

PRINT, x, y

ysize=N_ELEMENTS(y); number of points
npoints=FINDGEN(ysize)
PRINT, npoints, y
PLOT, npoints+1, y, XRANGE=[0,ysize+1], PSYM=1

con = 1.0 ;conversion factor
y = con * y
y_err = con * y_err

; set up vectors for plotting errorbars
yup = y - y_err
ydown = y + y_err

; plot data
xaxis_fac=0.9 ;to set up the maximum x-value in the plot
xmax=xaxis_fac*MAX(x)
yaxis_fac=0.9 ;to set up the maximum y-value in the plot
ymax=yaxis_fac*MAX(y)

; set up for postscript file output
SET_PLOT, 'ps'
DEVICE, filename='plot.ps'
  
PLOT, x, y, XRANGE=[0,xmax], YRANGE=[0,ymax], PSYM=7, $
	XTITLE='X', YTITLE='Y'

; overplot errors

	for i = 0,4 do begin

		ex = [x(i),x(i)]
		ey = [ydown(i), yup(i)]

		OPLOT, ex, ey

	endfor

DEVICE, /close
SET_PLOT, 'x'
FREE_LUN, unit

end
